@@ -1,4 +1,3 @@
-from . import models
 from . import logic
 from . import nn
 
@@ -6,7 +5,6 @@ from ._version import __version__
 
 __all__ = [
     'nn',
-    'models',
     'logic',
     '__version__'
 ]
